@@ -5,7 +5,7 @@
  * $Author: kou $
  * $Date: 2008-09-19 12:56:27 $
  *
- * Copyright 2006-2016 Kouhei Sutou <kou@cozmixng.org>
+ * Copyright 2006-2017 Kouhei Sutou <kou@cozmixng.org>
  * Copyright 2005 Øyvind Kolås <pippin@freedesktop.org>
  * Copyright 2004-2005 MenTaLguY <mental@rydia.com>
  *
@@ -73,7 +73,7 @@ RB_CAIRO_BEGIN_DECLS
 
 #define RB_CAIRO_VERSION_MAJOR 1
 #define RB_CAIRO_VERSION_MINOR 15
-#define RB_CAIRO_VERSION_MICRO 3
+#define RB_CAIRO_VERSION_MICRO 7
 
 RB_CAIRO_VAR VALUE rb_mCairo;
 RB_CAIRO_VAR VALUE rb_cCairo_Context;
@@ -160,6 +160,8 @@ RB_CAIRO_VAR VALUE rb_mCairo_TextClusterFlag;
 RB_CAIRO_VAR VALUE rb_mCairo_ScriptMode;
 RB_CAIRO_VAR VALUE rb_mCairo_MimeType;
 RB_CAIRO_VAR VALUE rb_mCairo_RegionOverlap;
+RB_CAIRO_VAR VALUE rb_mCairo_PDFOutlineFlags;
+RB_CAIRO_VAR VALUE rb_mCairo_PDFMetadata;
 RB_CAIRO_VAR VALUE rb_mCairo_Color;
 RB_CAIRO_VAR VALUE rb_cCairo_Color_Base;
 RB_CAIRO_VAR VALUE rb_cCairo_Paper;
@@ -298,6 +300,10 @@ VALUE                 rb_cairo_device_to_ruby_object         (cairo_device_t *de
 #if CAIRO_CHECK_VERSION(1, 10, 0)
 #define RVAL2CRREGIONOVERLAP(obj) (rb_cairo_region_overlap_from_ruby_object(obj))
 #endif
+#if CAIRO_CHECK_VERSION(1, 15, 4)
+#define RVAL2CRPDFOUTLINEFLAGS(obj) (rb_cairo_pdf_outline_flags_from_ruby_object(obj))
+#define RVAL2CRPDFMETADATA(obj) (rb_cairo_pdf_metadata_from_ruby_object(obj))
+#endif
 
 cairo_operator_t       rb_cairo_operator_from_ruby_object       (VALUE obj);
 cairo_antialias_t      rb_cairo_antialias_from_ruby_object      (VALUE obj);
@@ -336,6 +342,10 @@ cairo_script_mode_t     rb_cairo_script_mode_from_ruby_object   (VALUE obj);
 #if CAIRO_CHECK_VERSION(1, 10, 0)
 cairo_region_overlap_t  rb_cairo_region_overlap_from_ruby_object(VALUE obj);
 #endif
+#if CAIRO_CHECK_VERSION(1, 15, 4)
+cairo_pdf_outline_flags_t rb_cairo_pdf_outline_flags_from_ruby_object(VALUE obj);
+cairo_pdf_metadata_t rb_cairo_pdf_metadata_from_ruby_object(VALUE obj);
+#endif
 
 void rb_cairo_check_status (cairo_status_t status);
 void rb_cairo_surface_check_status (cairo_surface_t *surface);
